package config

import (
	"errors"
	"io/ioutil"
	"os"
	"path"

	"git.trj.tw/golang/utils"
	"gopkg.in/yaml.v2"
)

// Config -
type Config struct {
	Src  string `yaml:"src"`
	Dist string `yaml:"dist"`
}

var conf *Config

// LoadConfig -
func LoadConfig(p ...string) error {
	var fp string

	if len(p) > 0 && len(p[0]) > 0 {
		fp = p[0]
	} else {
		wd, err := os.Getwd()
		if err != nil {
			return err
		}
		fp = path.Join(wd, "config.yml")
	}

	fp = utils.ParsePath(fp)
	if exists := utils.CheckExists(fp, false); !exists {
		return errors.New("config not found")
	}

	dataByte, err := ioutil.ReadFile(fp)
	if err != nil {
		return err
	}

	conf = &Config{}

	err = yaml.Unmarshal(dataByte, conf)
	if err != nil {
		return err
	}

	return nil
}

// GetConfig -
func GetConfig() *Config { return conf }
